==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkXMLReader.java <==
// java wrapper for vtkXMLReader object
//

package vtk;
import vtk.*;

public class vtkXMLReader extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetReadFromInputString_4(int id0);
  public void SetReadFromInputString(int id0)
    { SetReadFromInputString_4(id0); }

  private native int GetReadFromInputString_5();
  public int GetReadFromInputString()
    { return GetReadFromInputString_5(); }

  private native void ReadFromInputStringOn_6();
  public void ReadFromInputStringOn()
    { ReadFromInputStringOn_6(); }

  private native void ReadFromInputStringOff_7();
  public void ReadFromInputStringOff()
    { ReadFromInputStringOff_7(); }

  private native void SetInputString_8(String id0);
  public void SetInputString(String id0)
    { SetInputString_8(id0); }

  private native int CanReadFile_9(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_9(id0); }

  private native long GetOutputAsDataSet_10();
  public vtkDataSet GetOutputAsDataSet() {
    long temp = GetOutputAsDataSet_10();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetOutputAsDataSet_11(int id0);
  public vtkDataSet GetOutputAsDataSet(int id0) {
    long temp = GetOutputAsDataSet_11(id0);

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPointDataArraySelection_12();
  public vtkDataArraySelection GetPointDataArraySelection() {
    long temp = GetPointDataArraySelection_12();

    if (temp == 0) return null;
    return (vtkDataArraySelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetCellDataArraySelection_13();
  public vtkDataArraySelection GetCellDataArraySelection() {
    long temp = GetCellDataArraySelection_13();

    if (temp == 0) return null;
    return (vtkDataArraySelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfPointArrays_14();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_14(); }

  private native int GetNumberOfCellArrays_15();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_15(); }

  private native String GetPointArrayName_16(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_16(id0); }

  private native String GetCellArrayName_17(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_17(id0); }

  private native int GetPointArrayStatus_18(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_18(id0); }

  private native int GetCellArrayStatus_19(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_19(id0); }

  private native void SetPointArrayStatus_20(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_20(id0,id1); }

  private native void SetCellArrayStatus_21(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_21(id0,id1); }

  private native void CopyOutputInformation_22(vtkInformation id0,int id1);
  public void CopyOutputInformation(vtkInformation id0,int id1)
    { CopyOutputInformation_22(id0,id1); }

  private native void SetTimeStep_23(int id0);
  public void SetTimeStep(int id0)
    { SetTimeStep_23(id0); }

  private native int GetTimeStep_24();
  public int GetTimeStep()
    { return GetTimeStep_24(); }

  private native int GetNumberOfTimeSteps_25();
  public int GetNumberOfTimeSteps()
    { return GetNumberOfTimeSteps_25(); }

  private native int[]  GetTimeStepRange_26();
  public int[]  GetTimeStepRange()
    { return GetTimeStepRange_26(); }

  private native void SetTimeStepRange_27(int id0,int id1);
  public void SetTimeStepRange(int id0,int id1)
    { SetTimeStepRange_27(id0,id1); }

  private native void SetTimeStepRange_28(int id0[]);
  public void SetTimeStepRange(int id0[])
    { SetTimeStepRange_28(id0); }

  private native long GetXMLParser_29();
  public vtkXMLDataParser GetXMLParser() {
    long temp = GetXMLParser_29();

    if (temp == 0) return null;
    return (vtkXMLDataParser)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkXMLReader() { super(); }

  public vtkXMLReader(long id) { super(id); }

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkXMLReader.java <==
// java wrapper for vtkXMLReader object
//

package vtk;
import vtk.*;

public class vtkXMLReader extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetReadFromInputString_4(int id0);
  public void SetReadFromInputString(int id0)
    { SetReadFromInputString_4(id0); }

  private native int GetReadFromInputString_5();
  public int GetReadFromInputString()
    { return GetReadFromInputString_5(); }

  private native void ReadFromInputStringOn_6();
  public void ReadFromInputStringOn()
    { ReadFromInputStringOn_6(); }

  private native void ReadFromInputStringOff_7();
  public void ReadFromInputStringOff()
    { ReadFromInputStringOff_7(); }

  private native void SetInputString_8(String id0);
  public void SetInputString(String id0)
    { SetInputString_8(id0); }

  private native int CanReadFile_9(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_9(id0); }

  private native long GetOutputAsDataSet_10();
  public vtkDataSet GetOutputAsDataSet() {
    long temp = GetOutputAsDataSet_10();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutputAsDataSet_11(int id0);
  public vtkDataSet GetOutputAsDataSet(int id0) {
    long temp = GetOutputAsDataSet_11(id0);

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPointDataArraySelection_12();
  public vtkDataArraySelection GetPointDataArraySelection() {
    long temp = GetPointDataArraySelection_12();

    if (temp == 0) return null;
    return (vtkDataArraySelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCellDataArraySelection_13();
  public vtkDataArraySelection GetCellDataArraySelection() {
    long temp = GetCellDataArraySelection_13();

    if (temp == 0) return null;
    return (vtkDataArraySelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfPointArrays_14();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_14(); }

  private native int GetNumberOfCellArrays_15();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_15(); }

  private native String GetPointArrayName_16(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_16(id0); }

  private native String GetCellArrayName_17(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_17(id0); }

  private native int GetPointArrayStatus_18(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_18(id0); }

  private native int GetCellArrayStatus_19(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_19(id0); }

  private native void SetPointArrayStatus_20(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_20(id0,id1); }

  private native void SetCellArrayStatus_21(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_21(id0,id1); }

  private native void CopyOutputInformation_22(vtkInformation id0,int id1);
  public void CopyOutputInformation(vtkInformation id0,int id1)
    { CopyOutputInformation_22(id0,id1); }

  private native void SetTimeStep_23(int id0);
  public void SetTimeStep(int id0)
    { SetTimeStep_23(id0); }

  private native int GetTimeStep_24();
  public int GetTimeStep()
    { return GetTimeStep_24(); }

  private native int GetNumberOfTimeSteps_25();
  public int GetNumberOfTimeSteps()
    { return GetNumberOfTimeSteps_25(); }

  private native int[]  GetTimeStepRange_26();
  public int[]  GetTimeStepRange()
    { return GetTimeStepRange_26(); }

  private native void SetTimeStepRange_27(int id0,int id1);
  public void SetTimeStepRange(int id0,int id1)
    { SetTimeStepRange_27(id0,id1); }

  private native void SetTimeStepRange_28(int id0[]);
  public void SetTimeStepRange(int id0[])
    { SetTimeStepRange_28(id0); }

  private native long GetXMLParser_29();
  public vtkXMLDataParser GetXMLParser() {
    long temp = GetXMLParser_29();

    if (temp == 0) return null;
    return (vtkXMLDataParser)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetReaderErrorObserver_30(vtkCommand id0);
  public void SetReaderErrorObserver(vtkCommand id0)
    { SetReaderErrorObserver_30(id0); }

  private native long GetReaderErrorObserver_31();
  public vtkCommand GetReaderErrorObserver() {
    long temp = GetReaderErrorObserver_31();

    if (temp == 0) return null;
    return (vtkCommand)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetParserErrorObserver_32(vtkCommand id0);
  public void SetParserErrorObserver(vtkCommand id0)
    { SetParserErrorObserver_32(id0); }

  private native long GetParserErrorObserver_33();
  public vtkCommand GetParserErrorObserver() {
    long temp = GetParserErrorObserver_33();

    if (temp == 0) return null;
    return (vtkCommand)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkXMLReader() { super(); }

  public vtkXMLReader(long id) { super(id); }

}
